@@ -17,7 +17,7 @@ class MyForm(QtGui.QMainWindow):
 		QtCore.QObject.connect(self.ui.Button, QtCore.SIGNAL('clicked()'), self.doRestore)
 
 		#load settings
-		f = open("/home/user/.config/savepress")
+		f = open("/home/user/MyDocs/.savepress")
 		for line in f:
 			if "vmax:" in line:
 				result = re.search('(?<=: )\w+', line)
@@ -69,7 +69,7 @@ class MyForm(QtGui.QMainWindow):
 
 
 	def doSave(self):
-		f = open('/home/user/.config/savepress', 'w')
+		f = open('/home/user/MyDocs/.savepress', 'w')
 		vmax = (self.ui.vmax.text())
 		vmin = (self.ui.vmin.text())
 		vdelay = (self.ui.vdelay.text())
